@@ -10,9 +10,12 @@ Behavior:
 """
 
 import os
+import sys
+from typing import Literal
 
 import yaml
 
+from deeporigin.utils.constants import ENV_VARIABLES
 from deeporigin.utils.core import _ensure_do_folder
 
 CONFIG_YML_LOCATION = _ensure_do_folder() / "config.yml"
@@ -30,6 +33,21 @@ def _ensure_config_file_exists() -> None:
             yaml.safe_dump(default_data, file, default_flow_style=False)
 
 
+def _supports_unicode_output() -> bool:
+    """Return True if stdout likely supports Unicode glyphs.
+
+    Uses the encoding reported by `sys.stdout.encoding` and falls back to
+    `utf-8` heuristic. On Windows default code pages (e.g., cp1252), returns
+    False to avoid `UnicodeEncodeError`.
+    """
+
+    encoding: str | None = getattr(sys.stdout, "encoding", None)
+    if not encoding:
+        return False
+    encoding_lower = encoding.lower()
+    return "utf" in encoding_lower
+
+
 def get_value() -> dict:
     """Get the configuration values.
 
@@ -50,12 +68,18 @@ def get_value() -> dict:
 
     # Fill defaults if missing
     env = data.get("env", "prod")
-    org_key = data.get("org_key", "")
+    org_key = data.get("org_key", None)
+
+    # env variables override config file
+    if ENV_VARIABLES["env"] in os.environ:
+        env = os.environ[ENV_VARIABLES["env"]]
+    if ENV_VARIABLES["org_key"] in os.environ:
+        org_key = os.environ[ENV_VARIABLES["org_key"]]
 
     return {"env": env, "org_key": org_key}
 
 
-def set_value(key: str, value) -> None:
+def set_value(key: Literal["env", "org_key"], value) -> None:
     """Set a configuration value.
 
     Only `env` and `org_key` are supported keys.
@@ -81,4 +105,9 @@ def set_value(key: str, value) -> None:
     with open(CONFIG_YML_LOCATION, "w") as file:
         yaml.safe_dump(data, file, default_flow_style=False)
 
-    print(f"✔︎ {key} → {value}")
+    # Prefer Unicode on capable terminals; fall back to ASCII-safe symbols
+    if _supports_unicode_output():
+        check, arrow = "✔︎", "→"
+    else:
+        check, arrow = "OK", "->"
+    print(f"{check} {key} {arrow} {value}")
