@@ -119,9 +119,8 @@ class Docking(WorkflowStep):
     def get_results(self, *, file_type: str = "csv") -> pd.DataFrame | None | list[str]:
         """return a list of paths to CSV files that contain the results from docking"""
 
-        files = utils.find_files_on_ufa(
-            tool="Docking",
-            protein=self.parent.protein.file_path.name,
+        files = file_api.list_files_in_dir(
+            file_path="tool-runs/Docking/" + self.parent.protein.to_hash() + "/",
             client=self.parent.client,
         )
 
@@ -172,7 +171,6 @@ class Docking(WorkflowStep):
         *,
         pocket_center=None,
         box_size=None,
-        only_with_status: Optional[list[str]] = None,
     ):
         """search for all jobs that match this protein and ligands in the Job DB, and return a dataframe of the results"""
 
@@ -182,6 +180,7 @@ class Docking(WorkflowStep):
             include_metadata=True,
             include_inputs=True,
             include_outputs=True,
+            client=self.parent.client,
         )
 
         if pocket_center is not None and len(df) > 0:
@@ -199,10 +198,17 @@ class Docking(WorkflowStep):
             df = df[mask]
 
         # filter to only keep jobs that match this protein.
-        protein_basename = os.path.basename(self.parent.protein.file_path)
-
         if "metadata" in df.columns and len(df) > 0:
-            mask = df["metadata"].apply(lambda x: x["protein_file"] == protein_basename)
+            # first, drop rows where metadata has no protein_hash key
+            has_protein_hash = df["metadata"].apply(
+                lambda x: isinstance(x, dict) and ("protein_hash" in x)
+            )
+            df = df[has_protein_hash]
+
+            # then, keep only rows matching this protein hash
+            mask = df["metadata"].apply(
+                lambda x: x["protein_hash"] == self.parent.protein.to_hash()
+            )
             df = df[mask]
 
         if "user_inputs" in df.columns and len(df) > 0:
@@ -226,6 +232,7 @@ class Docking(WorkflowStep):
         n_workers: Optional[int] = None,
         _output_dir_path: Optional[str] = None,
         use_parallel: bool = True,
+        re_run: bool = False,
     ):
         """Run bulk docking on Deep Origin. Ligands will be split into batches based on the batch_size argument, and will run in parallel on Deep Origin clusters.
 
@@ -235,16 +242,22 @@ class Docking(WorkflowStep):
             batch_size (int, optional): batch size. Defaults to 30.
             n_workers (int, optional): number of workers. Defaults to None.
             use_parallel (bool, optional): whether to run jobs in parallel. Defaults to True.
+            re_run (bool, optional): whether to re-run jobs. Defaults to False.
         """
 
         protein_basename = os.path.basename(self.parent.protein.file_path)
 
         if _output_dir_path is None:
-            _output_dir_path = "tool-runs/Docking/" + protein_basename + "/"
+            _output_dir_path = (
+                "tool-runs/Docking/" + self.parent.protein.to_hash() + "/"
+            )
 
         self.parent._sync_protein_and_ligands()
 
-        metadata = dict(protein_file=protein_basename)
+        metadata = {
+            "protein_file": protein_basename,
+            "protein_hash": self.parent.protein.to_hash(),
+        }
 
         if batch_size is None and n_workers is None:
             raise DeepOriginException(
@@ -276,12 +289,14 @@ class Docking(WorkflowStep):
         df = self._get_jobs(pocket_center=pocket_center, box_size=box_size)
 
         already_docked_ligands = []
-        for _, row in df.iterrows():
-            this_smiles = row["user_inputs"]["smiles_list"]
-            already_docked_ligands.extend(this_smiles)
+
+        if not re_run:
+            for _, row in df.iterrows():
+                this_smiles = row["user_inputs"]["smiles_list"]
+                already_docked_ligands.extend(this_smiles)
 
         smiles_strings = set(smiles_strings) - set(already_docked_ligands)
-        smiles_strings = list(smiles_strings)
+        smiles_strings = sorted(smiles_strings)
 
         print(
             f"Docking {len(smiles_strings)} ligands, after filtering out already docked ligands..."
@@ -303,7 +318,7 @@ class Docking(WorkflowStep):
 
             # Create a stable hash for the chunk
             chunk_str = ",".join(chunk)
-            chunk_hash = hashlib.md5(chunk_str.encode("utf-8")).hexdigest()
+            chunk_hash = hashlib.md5(chunk_str.encode("utf-8")).hexdigest()  # NOSONAR
             this_output_dir_path = os.path.join(_output_dir_path, chunk_hash) + "/"
 
             return utils._start_tool_run(
@@ -343,7 +358,7 @@ class Docking(WorkflowStep):
         else:
             print("No new ligands to dock")
 
-        job = Job.from_ids(job_ids)
+        job = Job.from_ids(job_ids, client=self.parent.client)
         # for docking, we always have a single job
         self.jobs = [job]
 
