@@ -23,7 +23,7 @@ from tqdm import tqdm
 from deeporigin.drug_discovery.constants import LIGANDS_DIR
 from deeporigin.drug_discovery.utilities.visualize import jupyter_visualization
 from deeporigin.exceptions import DeepOriginException
-from deeporigin.utils.constants import number
+from deeporigin.utils.constants import SUPPORTED_ATOM_SYMBOLS, number
 
 from .entity import Entity
 
@@ -346,12 +346,78 @@ class Ligand(Entity):
 
         self.mol = stripped_mol
 
+    @beartype
+    def prepare(self, *, remove_hydrogens: bool = False) -> "Ligand":
+        """Prepare the ligand for downstream workflows.
+
+        The routine performs the following using RDKit and internal utilities:
+        - Salt removal
+        - Kekulization
+        - Validation of atom types against supported symbols
+
+        Args:
+            remove_hydrogens (bool): Whether to remove hydrogens from the SMILES representation.
+                                   Defaults to False (preserve hydrogens).
+
+        Returns:
+            Ligand: The prepared ligand (self), for chaining.
+
+        Raises:
+            DeepOriginException: If preparation fails or unsupported atom types are present.
+        """
+        # Start from current molecule
+        if self.mol is None:
+            raise DeepOriginException("Ligand has no molecule to prepare.")
+
+        # 1) Salt removal and kekulization (reuse process_mol)
+        self.process_mol()
+
+        # 2) Sanity sanitize and generate 2D coords if missing
+        try:
+            Chem.SanitizeMol(self.mol)
+        except Exception:
+            # Attempt to re-kekulize and sanitize again
+            try:
+                Chem.Kekulize(self.mol, clearAromaticFlags=False)
+                Chem.SanitizeMol(self.mol)
+            except Exception as e:
+                raise DeepOriginException(f"Sanitization failed: {str(e)}") from e
+
+        if not self.mol.GetConformers():
+            AllChem.Compute2DCoords(self.mol)
+
+        # 3) Validate atom types
+        atom_symbols = [atom.GetSymbol() for atom in self.mol.GetAtoms()]
+        unsupported = sorted(
+            {sym for sym in atom_symbols if sym not in SUPPORTED_ATOM_SYMBOLS}
+        )
+        if unsupported:
+            raise DeepOriginException(
+                f"Unsupported atom types found in ligand: {', '.join(unsupported)}"
+            )
+
+        # Update smiles and properties to reflect prepared state
+        if remove_hydrogens:
+            self.smiles = Chem.MolToSmiles(Chem.RemoveHs(self.mol), canonical=True)
+        else:
+            self.smiles = Chem.MolToSmiles(self.mol, canonical=True)
+        self.set_property("prepared", True)
+
+        return self
+
     def get_heavy_atom_count(self) -> int:
         """
         Get the number of heavy atoms in the molecule.
         """
         return self.mol.GetNumHeavyAtoms()
 
+    def is_charged(self) -> bool:
+        """
+        Check if the molecule is charged.
+        """
+        total_charge = sum(atom.GetFormalCharge() for atom in self.mol.GetAtoms())
+        return total_charge != 0
+
     def get_conformer(self, conformer_id: int = 0):
         """
         Get a specific conformer of the molecule.
@@ -680,10 +746,15 @@ class Ligand(Entity):
         # Create a temporary SDF file
         temp_sdf_path = self.to_sdf("__ligand_hash__.sdf")
 
-        # Read the file and compute SHA256 hash
-        with open(temp_sdf_path, "rb") as f:
-            sdf_content = f.read()
-            hash_object = hashlib.sha256(sdf_content)
+        # Read the file in text mode, normalize newlines, and compute SHA256
+        with open(temp_sdf_path, "r", newline="") as f:
+            sdf_text = f.read()
+            # Normalize all line endings to \n for OS-agnostic hashing
+            normalized_text = sdf_text.replace("\r\n", "\n").replace("\r", "\n")
+            # Ensure file ends with a single newline to avoid platform differences
+            if not normalized_text.endswith("\n"):
+                normalized_text = f"{normalized_text}\n"
+            hash_object = hashlib.sha256(normalized_text.encode("utf-8"))
             hash_hex = hash_object.hexdigest()
 
         # Clean up the temporary file
@@ -1034,7 +1105,7 @@ class LigandSet:
                 f"Cannot sample {n} ligands from a set of {len(self.ligands)} ligands"
             )
 
-        sampled_ligands = random.sample(self.ligands, n)
+        sampled_ligands = random.sample(self.ligands, n)  # NOSONAR
         return LigandSet(ligands=sampled_ligands)
 
     def _repr_html_(self):
