@@ -20,12 +20,26 @@ import pandas as pd
 from deeporigin.drug_discovery.constants import tool_mapper
 from deeporigin.platform import Client, tools_api
 from deeporigin.tools import job_viz_functions
+from deeporigin.utils.constants import TERMINAL_STATES
 from deeporigin.utils.core import elapsed_minutes
 
 # Enable nested event loops for Jupyter
 nest_asyncio.apply()
 
 
+# Get the template directory
+template_dir = Path(__file__).parent.parent / "templates"
+# Create Jinja2 environment with auto-escaping disabled
+# Note: Auto-escaping is disabled because the template needs to render HTML content
+# from _viz_func and properly formatted JSON data. The |safe filter is used
+# only for trusted content (JSON data and HTML from _viz_func).
+# All other template variables are properly escaped by the template itself.
+env = Environment(  # NOSONAR
+    loader=FileSystemLoader(str(template_dir)),
+    autoescape=False,
+)
+
+
 class JobFunc(Protocol):
     """A protocol for functions that can be used to visualize a job or render a name for a job."""
 
@@ -57,9 +71,11 @@ class Job:
     _outputs: list = field(default_factory=list)
     _task = None
     _attributes: list = field(default_factory=list)
-    _execution_ids: list = field(default_factory=list)
+    _resource_ids: list = field(default_factory=list)
     _metadata: list = field(default_factory=list)
     _tool: dict = field(default_factory=dict)
+    _display_id: Optional[str] = None
+    _last_html: Optional[str] = None
 
     # clients
     client: Optional[Client] = None
@@ -143,7 +159,7 @@ class Job:
         self._attributes = results
         self._status = [result["status"] for result in results]
         self._progress_reports = [result["progressReport"] for result in results]
-        self._execution_ids = [result["executionId"] for result in results]
+        self._resource_ids = [result["resourceId"] for result in results]
         self._inputs = [result["userInputs"] for result in results]
         self._outputs = [result["userOutputs"] for result in results]
         self._metadata = [result["metadata"] for result in results]
@@ -171,17 +187,6 @@ class Job:
         This method renders and displays the current state of all jobs
         using the visualization function if set, or a default HTML representation.
         """
-        # Get the template directory
-        template_dir = Path(__file__).parent.parent / "templates"
-        # Create Jinja2 environment with auto-escaping disabled
-        # Note: Auto-escaping is disabled because the template needs to render HTML content
-        # from _viz_func and properly formatted JSON data. The |safe filter is used
-        # only for trusted content (JSON data and HTML from _viz_func).
-        # All other template variables are properly escaped by the template itself.
-        env = Environment(
-            loader=FileSystemLoader(str(template_dir)),
-            autoescape=False,  # Disabled for proper HTML and JSON rendering
-        )
 
         from deeporigin.utils.notebook import get_notebook_environment
 
@@ -222,7 +227,7 @@ class Job:
             "outputs_json": json.dumps(self._outputs, indent=2),
             "inputs_json": json.dumps(self._inputs, indent=2),
             "job_ids": self._ids,
-            "execution_ids": self._execution_ids,
+            "resource_ids": self._resource_ids,
             "statuses": self._status,
             "started_at": started_at,
             "running_time": running_time,
@@ -264,6 +269,24 @@ class Job:
         # Render the template
         return template.render(**template_vars)
 
+    @beartype
+    def _compose_error_overlay_html(self, *, message: str) -> str:
+        """Compose an error overlay banner HTML for transient failures.
+
+        Args:
+            message: Error message to display.
+
+        Returns:
+            HTML string for an overlay banner indicating a temporary issue.
+        """
+        timestamp = time.strftime("%Y-%m-%d %H:%M:%S")
+        return (
+            "<div style='background: #fff4f4; border: 1px solid #f0b5b5; color: #8a1f1f;"
+            " padding: 8px 12px; margin-bottom: 8px; border-radius: 6px;'>"
+            f"Network/update issue at {timestamp}. Will retry automatically. Error: {message}"
+            "</div>"
+        )
+
     def show(self):
         """Display the job view in a Jupyter notebook.
 
@@ -281,8 +304,8 @@ class Job:
         active jobs to monitor, it will display a message and show the current
         state once.
         """
-        # Check if there are any active jobs (not Failed or Succeeded)
-        if not any(status not in ["Failed", "Succeeded"] for status in self._status):
+        # Check if there are any active jobs (not terminal states)
+        if not any(status not in TERMINAL_STATES for status in self._status):
             display(
                 HTML(
                     "<div style='color: gray;'>No active jobs to monitor. This display will not update.</div>"
@@ -297,7 +320,8 @@ class Job:
         # for reasons i don't understand, removing this breaks the display rendering
         # when we do job.watch()
         initial_html = HTML("<div style='color: gray;'>Initializing...</div>")
-        display_id = "timestamp_display"
+        display_id = str(uuid.uuid4())
+        self._display_id = display_id
         display(initial_html, display_id=display_id)
 
         async def update_progress_report():
@@ -307,18 +331,46 @@ class Job:
             with the latest job status and progress every 5 seconds.
             It automatically stops when all jobs reach a terminal state.
             """
-            while True:
-                self.sync()
-                html = self._render_job_view(will_auto_update=True)
+            try:
+                while True:
+                    try:
+                        # Run sync in a worker thread with a timeout to avoid indefinite blocking
+                        await asyncio.wait_for(asyncio.to_thread(self.sync), timeout=4)
 
-                update_display(HTML(html), display_id=display_id)
+                        html = self._render_job_view(will_auto_update=True)
+                        update_display(HTML(html), display_id=self._display_id)
+                        self._last_html = html
 
-                # Check if all jobs are in terminal states
-                if all(status in ["Failed", "Succeeded"] for status in self._status):
-                    self.stop_watching()
-                    break
+                        # Check if all jobs are in terminal states
+                        if all(status in TERMINAL_STATES for status in self._status):
+                            break
 
-                await asyncio.sleep(5)
+                    except Exception as e:
+                        # Show a transient error banner, but keep the task alive
+                        banner = self._compose_error_overlay_html(message=str(e))
+                        fallback = (
+                            self._last_html
+                            or "<div style='color: gray;'>No data yet.</div>"
+                        )
+                        update_display(
+                            HTML(banner + fallback), display_id=self._display_id
+                        )
+
+                    # Always sleep 5 seconds before next attempt
+                    await asyncio.sleep(5)
+            finally:
+                # Perform a final non-blocking refresh and render to clear spinner
+                if self._display_id is not None:
+                    try:
+                        await asyncio.wait_for(asyncio.to_thread(self.sync), timeout=5)
+                    except Exception:
+                        pass
+                    try:
+                        final_html = self._render_job_view(will_auto_update=False)
+                        update_display(HTML(final_html), display_id=self._display_id)
+                    except Exception:
+                        pass
+                    self._display_id = None
 
         # Schedule the task.
         self._task = asyncio.create_task(update_progress_report())
@@ -331,8 +383,13 @@ class Job:
         or can be called manually to stop monitoring.
         """
         if self._task is not None:
-            self._task.cancel()  # note that this is not job.cancel() -- we're cancelling the asyncio task
-            self._task = None
+            # Cancel the task; its finally block performs the final render and cleanup
+            try:
+                self._task.cancel()
+            except Exception:
+                pass
+            finally:
+                self._task = None
 
     def _repr_html_(self) -> str:
         """Return HTML representation for Jupyter notebooks.
@@ -362,6 +419,8 @@ class Job:
             client=self.client,
         )
 
+        self.sync()
+
 
 # @beartype
 def get_dataframe(
@@ -430,7 +489,7 @@ def get_dataframe(
     data = {
         "id": [],
         "created_at": [],  # converting some fields to snake_case
-        "execution_id": [],
+        "resource_id": [],
         "completed_at": [],
         "started_at": [],
         "status": [],
@@ -452,9 +511,9 @@ def get_dataframe(
 
     for job in jobs:
         # Add basic fields
-        data["id"].append(job["id"])
+        data["id"].append(job["executionId"])
         data["created_at"].append(job["createdAt"])
-        data["execution_id"].append(job["executionId"])
+        data["resource_id"].append(job["resourceId"])
         data["completed_at"].append(job["completedAt"])
         data["started_at"].append(job["startedAt"])
         data["status"].append(job["status"])
